// Deletes a preference
function joleraser_deletePreference(preference)
{
    // If the preference is set
    if(preference)
    {
        // If a user preference is set
        if(joleraser_isPreferenceSet(preference))
        {
            Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").clearUserPref(preference);
        }
    }
}

// Deletes a preference branch
function joleraser_deletePreferenceBranch(branch)
{
    // If the branch is set
    if(branch)
    {
        Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").deleteBranch(branch);
    }
}

// Gets a boolean preference, returning false if the preference is not set
function joleraser_getBooleanPreference(preference, userPreference)
{
    // If the preference is set
    if(preference)
    {
        // If not a user preference or a user preference is set
        if(!userPreference || joleraser_isPreferenceSet(preference))
        {
            try
            {
                return Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").getBoolPref(preference);
            }
            catch(exception)
            {
                // Do nothing
            }
        }
    }

    return false;
}

// Gets an integer preference, returning 0 if the preference is not set
function joleraser_getIntegerPreference(preference, userPreference)
{
    // If the preference is set
    if(preference)
    {
        // If not a user preference or a user preference is set
        if(!userPreference || joleraser_isPreferenceSet(preference))
        {
            try
            {
                return Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").getIntPref(preference);
            }
            catch(exception)
            {
                // Do nothing
            }
        }
    }

    return 0;
}

// Gets a string preference, returning null if the preference is not set
function joleraser_getStringPreference(preference, userPreference)
{
    // If the preference is set
    if(preference)
    {
        // If not a user preference or a user preference is set
        if(!userPreference || joleraser_isPreferenceSet(preference))
        {
            try
            {
                return Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").getCharPref(preference);
            }
            catch(exception)
            {
				alert("catch");
                // Do nothing
            }
        }
    }

    return null;
}

// Is a preference set
function joleraser_isPreferenceSet(preference)
{
    // If the preference is set
    if(preference)
    {
        return Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").prefHasUserValue(preference);
    }

    return false;
}

// Sets a boolean preference
function joleraser_setBooleanPreference(preference, value)
{
    // If the preference is set
    if(preference)
    {
        Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").setBoolPref(preference, value);
    }
}

// Sets a boolean preference if it is not already set
function joleraser_setBooleanPreferenceIfNotSet(preference, value)
{
    // If the preference is not set
    if(!joleraser_isPreferenceSet(preference))
    {
        Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").setBoolPref(preference, value);
    }
}

// Sets an integer preference
function joleraser_setIntegerPreference(preference, value)
{
    // If the preference is set
    if(preference)
    {
        Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").setIntPref(preference, value);
    }
}

// Sets an integer preference if it is not already set
function joleraser_setIntegerPreferenceIfNotSet(preference, value)
{
    // If the preference is not set
    if(!joleraser_isPreferenceSet(preference))
    {
        joleraser_setIntegerPreference(preference, value);
    }
}

// Sets a string preference
function joleraser_setStringPreference(preference, value)
{
    // If the preference is set
    if(preference)
    {
        Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("").setCharPref(preference, value);
    }
}

// Sets a string preference if it is not already set
function joleraser_setStringPreferenceIfNotSet(preference, value)
{
    // If the preference is not set
    if(!joleraser_isPreferenceSet(preference))
    {
        joleraser_setStringPreference(preference, value);
    }
}